@@ -233,6 +233,13 @@ gint zg_button_press_event(GtkWidget *widget, GdkEventButton *event)
   return TRUE;
 }
 
+gint zg_destroy_event(GtkWidget *widget, GdkEventButton *event)
+{
+      gtk_exit(0);
+      exit(0);
+
+  return TRUE;
+}
 /*-----------------------------------------------*/
 static GtkWidget *zggdrw_(DCL_INT *width, DCL_INT *height)
 {
@@ -277,6 +284,9 @@ static GtkWidget *zggdrw_(DCL_INT *width, DCL_INT *height)
     gtk_signal_connect(GTK_OBJECT (drw), "expose_event",
 		       (GtkSignalFunc) zg_expose_event, NULL);
 
+    gtk_signal_connect(GTK_OBJECT (window), "destroy",
+		       (GtkSignalFunc) zg_destroy_event, NULL);
+
     gtk_widget_show(window);
   }
 
